@@ -1,5 +1,5 @@
 from .base import Base, Condition, DayTime, Lang, MoonCode, MoonText, PhenomCondition, PrecipitationType, Season, WindDir
 from .fact import Fact
 from .info import Info, TzInfo
-from .request import Request, RequestForecast
-from .response import Response, ResponseForecast
+from .request import Request, RequestForecast, RequestInformers
+from .response import Response, ResponseForecast, ResponseInformers
